`run_eph_al`:
Electron-phonon calculations.

`run_fe_ebands`:
Calculation of the band structure of Fe with and without magnetization.
See `~abinit/tutorial/Input/tspin_1.in`

`run_from_files`:
Flow for computing the band structure of silicon.

`run_gruneisen_phonopy_si`:
Compute phonon frequencies with phonopy (supercells and finite-difference method).

`run_gwconv_ecuteps`:
G0W0 convergence study wrt ecuteps and the number of bands in W.

`run_ht_si_bsemdf`:
Calculation of the BSE spectrum with the HT interface.

`run_ht_si_ebands`:
Band structure of silicon with the HT interface.

`run_ht_si_g0w0ppm`:
G0W0 corrections with the HT interface.

`run_ldaus`:
LDA+U band structure of NiO for several values of U-J.

`run_mgb2_edoses`:
Band structure and the electron DOS of MgB2 with different k-point samplings.

`run_optic`:
Optical spectra with Optic.

`run_phfrozen_bands`:
Band structure of silicon in a distorted geometry (frozen phonon at q=0)

`run_phonons`:
Phonon band structure of AlAs.

`run_phonopy_si`:
Compute phonon frequencies with phonopy (supercells and finite-difference method).

`run_qha`:
Flow for quasi-harmonic calculations

`run_qptdmscr`:
This example shows how to compute the SCR file by splitting the calculation of the SCR file
over q-points with the input variables nqptdm and qptdm.

`run_raman`:
This script shows how to perform a RAMAN calculation with 
excitonic effects included with the BSE formalism.

`run_raman_optic`:
This script shows how to perform a RAMAN calculation with excitonic effects 
included with the BSE formalism.

`run_relax`:
This script shows how to perform a structural relaxation in two steps:

    1) Relaxation of atomic positions with unit cell parameters fixed.

    2) Full relaxation (atoms + cell) with the initial configuration read from step 1)

`run_relax_and_ebands`:
This script shows how to perform a structural relaxation and a band structure calculation

WARNING: The API could change!

`run_si_ebands`:
Flow for computing the band structure of silicon.

`run_si_g0w0`:
This script shows how to compute the G0W0 corrections in silicon.

`run_sic_relax`:
Structural relaxation for SiC.

`run_wyckoff`:
This example shows how to compute the band structure of a set of
crystalline structures obtained by changing a set of internal paramaters

